============
Installation
============

If you're running on Ubuntu Xenial or greater::

    sudo apt-get install python-pylxd lxd

Otherwise you can track LXD development on other Ubuntu releases::

    sudo add-apt-repository ppa:ubuntu-lxc/lxd-git-master && sudo apt-get update
    sudo apt-get install lxd

Or install pylxd using pip::

    pip install pylxd
